import React from 'react'
import { FluidType } from 'enum/fluid.enum'
import { withStyles } from '@material-ui/core/styles'
import MuiCircularProgress, {
  CircularProgressProps,
} from '@material-ui/core/CircularProgress'

const SpinnerBase = withStyles({
  root: {
    color: 'var(--multiColor)',
  },
})(MuiCircularProgress)

const SpinnerElec = withStyles({
  root: {
    color: 'var(--elecColor)',
  },
})(MuiCircularProgress)

const SpinnerWater = withStyles({
  root: {
    color: 'var(--waterColor)',
  },
})(MuiCircularProgress)

const SpinnerGas = withStyles({
  root: {
    color: 'var(--gasColor)',
  },
})(MuiCircularProgress)

interface StyledSpinnerProps extends CircularProgressProps {
  fluidTypes?: FluidType[]
}

const StyledSpinner: React.ComponentType<StyledSpinnerProps> = ({
  fluidTypes,
  ...props
}: StyledSpinnerProps) => {
  if (!fluidTypes) {
    return <SpinnerBase {...props} />
  } else if (fluidTypes.length === 1) {
    switch (fluidTypes[0]) {
      case FluidType.ELECTRICITY:
        return <SpinnerElec {...props} />
      case FluidType.WATER:
        return <SpinnerWater {...props} />
      case FluidType.GAS:
        return <SpinnerGas {...props} />
      default:
        return <SpinnerBase {...props} />
    }
  }
  return <SpinnerBase {...props} />
}

export default StyledSpinner
