import React, { useState } from 'react'
import { translate } from 'cozy-ui/react/I18n'

import IFluidConfig from 'services/IFluidConfig'
import { Konnector, Trigger } from 'doctypes'

import KonnectorLoginForm from 'components/ContentComponents/Konnector/KonnectorLoginForm'
import KonnectorOAuthForm from 'components/ContentComponents/Konnector/KonnectorOAuthForm'
import KonnectorLoading from 'components/ContentComponents/Konnector/KonnectorLoading'

interface KonnectorFormProps {
  fluidConfig: IFluidConfig
  konnector: Konnector
  handleConnexion: Function
}

const KonnectorForm: React.FC<KonnectorFormProps> = ({
  fluidConfig,
  konnector,
  handleConnexion,
}: KonnectorFormProps) => {
  const oAuth: boolean = fluidConfig.konnectorConfig.oauth
  const [account, setAccount] = useState<Account | null>(null)
  const [trigger, setTrigger] = useState<Trigger | null>(null)

  const handleForm = (_account: Account, _trigger: Trigger) => {
    setAccount(_account)
    setTrigger(_trigger)
  }

  const handleKonnectorLoading = () => {
    handleConnexion(account)
  }

  return (
    <>
      {account && trigger ? (
        <KonnectorLoading
          trigger={trigger}
          handleKonnectorLoading={handleKonnectorLoading}
        />
      ) : !oAuth ? (
        <KonnectorLoginForm fluidConfig={fluidConfig} onSuccess={handleForm} />
      ) : (
        <KonnectorOAuthForm
          konnector={konnector}
          siteLink={fluidConfig.siteLink}
          onSuccess={handleForm}
        />
      )}
    </>
  )
}

export default translate()(KonnectorForm)
