import React, { useState, useEffect } from 'react'
import { withClient, Client } from 'cozy-client'
import { translate } from 'cozy-ui/react/I18n'

import { isKonnectorRunning } from 'cozy-harvest-lib/dist/helpers/triggers'
import {
  KonnectorJob,
  ERROR_EVENT,
  LOGIN_SUCCESS_EVENT,
  SUCCESS_EVENT,
} from 'cozy-harvest-lib/dist/models/KonnectorJob'
import { Trigger } from 'doctypes'

import Lottie from 'react-lottie'
import * as loadingData from 'assets/anims/bounceloading.json'

const loadingOptions = {
  loop: true,
  autoplay: true,
  animationData: loadingData,
  rendererSettings: {
    preserveAspectRatio: 'xMidYMid slice',
  },
}

interface KonnectorLoadingProps {
  trigger: Trigger
  handleKonnectorLoading: Function
  client: Client
  t: Function
}

const KonnectorLoading: React.FC<KonnectorLoadingProps> = ({
  trigger,
  handleKonnectorLoading,
  client,
  t,
}: KonnectorLoadingProps) => {
  const callbackResponse = (state: string) => {
    console.log('event', state)
    handleKonnectorLoading(state)
  }

  useEffect(() => {
    let subscribed = true
    async function getData() {
      if (!isKonnectorRunning(trigger)) {
        const konnectorJob = new KonnectorJob(client, trigger)
        const test = await konnectorJob.launch()
        console.log(test)
        console.log(konnectorJob)
        const result = konnectorJob.getStatus()
        console.log(result)
        const result2 = konnectorJob.jobWatcher
        console.log(result2)
        konnectorJob.jobWatcher.on(ERROR_EVENT, () => {
          callbackResponse(ERROR_EVENT)
        })
        konnectorJob.jobWatcher.on(LOGIN_SUCCESS_EVENT, () => {
          callbackResponse(LOGIN_SUCCESS_EVENT)
        })
        konnectorJob.jobWatcher.on(SUCCESS_EVENT, () => {
          callbackResponse(SUCCESS_EVENT)
        })
      }
    }
    getData()
    return () => {
      subscribed = false
    }
  }, [])

  return (
    <div className="kload-content">
      <Lottie options={loadingOptions} height={50} width={50} />
      <div className="kload-content-text kload-content-text-center text-16-normal">
        <div>{t('KONNECTORCONFIG.PLZ_WAIT')}</div>
      </div>
      <div className="kload-content-text text-16-normal">
        <div>{t('KONNECTORCONFIG.LOADING_DATA')}</div>
      </div>
    </div>
  )
}

export default translate()(withClient(KonnectorLoading))
