import React, { useState, useContext, useEffect } from 'react'
import { withClient, Client } from 'cozy-client'
import { translate } from 'cozy-ui/react/I18n'

import { AppContext } from 'components/Contexts/AppContextProvider'

import StyledButton from 'components/CommonKit/Button/StyledButton'
import StyledBlackSpinner from 'components/CommonKit/Spinner/StyledBlackSpinner'

import { Account, Konnector, Trigger } from 'doctypes'
import {
  getKonnectorJobError,
  getKonnectorStatus,
  getLastSuccessDate,
} from 'cozy-harvest-lib/dist/helpers/triggers'
import { TriggerService } from 'services/triggersService'
import { AccountService } from 'services/accountService'

interface KonnectorResultProps {
  account: Account
  konnector: Konnector
  client: Client
  t: Function
}

const KonnectorResult: React.FC<KonnectorResultProps> = ({
  account,
  konnector,
  client,
  t,
}: KonnectorResultProps) => {
  const [updating, setUpdating] = useState<boolean>(false)
  const [lastExecutionDate, setLastExecutionDate] = useState<string>('-')
  const [status, setStatus] = useState<string>('')

  const context = useContext(AppContext)

  // TODO - rework
  const updateKonnector = async () => {
    setUpdating(true)
    try {
      const triggersServices = new TriggerService(client, account, konnector)
      if (trigger !== null) {
        triggersServices.setTrigger(trigger)
      }
      const job = await triggersServices.launchTrigger()
      if (!job) {
        throw new Error(`Error during trigger launching`)
      }
      setlaunchedJob(job)
    } catch (error) {
      setUpdating(false)
    }
  }

  const deleteAccount = async () => {
    setUpdating(true)
    try {
      if (account) {
        const delAccount = await AccountService.deleteAccount(client, account)
        await context.refreshFluidTypes()
      }
    } catch (error) {
      setUpdating(false)
    }
  }

  useEffect(() => {
    let subscribed = true
    async function getData() {
      const _trigger = await TriggerService.fetchTriggerFromAccount(
        client,
        account
      )
      console.log(_trigger)
      if (subscribed && _trigger) {
        console.log('trigger', _trigger)
        const triggerState = await TriggerService.fetchTriggerState(
          client,
          _trigger
        )
        if (subscribed && triggerState) {
          console.log(triggerState)
          // TODO - format date
          setLastExecutionDate(
            new Date(triggerState.last_execution).toDateString()
          )
          setStatus(triggerState.status)
          await context.refreshFluidTypes()
        }
      }
    }
    getData()
    return () => {
      subscribed = false
    }
  }, [])

  return (
    <div className="accordion-update-result">
      <div className="accordion-update">
        <div
          className={
            status === 'errored'
              ? 'accordion-caption-red text-16-normal'
              : 'accordion-caption text-16-normal'
          }
        >
          {t('KONNECTORCONFIG.LABEL_UPDATEDAT')}
        </div>
        <div>{lastExecutionDate}</div>
      </div>
      <div className="inline-buttons">
        <StyledButton
          type="button"
          color="primary"
          onClick={updateKonnector}
          disabled={updating}
        >
          {updating ? (
            <StyledBlackSpinner size="2em" />
          ) : (
            <div>{t('KONNECTORCONFIG.BTN_UPDATE')}</div>
          )}
        </StyledButton>
        <StyledButton
          type="button"
          color="secondary"
          onClick={deleteAccount}
          disabled={updating}
        >
          {t('KONNECTORCONFIG.BTN_DELETE')}
        </StyledButton>
      </div>
    </div>
  )
}

export default translate()(withClient(KonnectorResult))
